@@ -476,22 +476,22 @@ static void meta_notify(NetEvent event, G_GNUC_UNUSED void *user_data,
 				g_assert(!strcmp(split_result[0], "goto"));
 				if (split_result[1]) {
 					if (metaserver_info.server)
-						g_free(metaserver_info.
-						       server);
+						g_free
+						    (metaserver_info.
+						     server);
 					metaserver_info.server =
 					    g_strdup(split_result[1]);
 					if (metaserver_info.port)
-						g_free(metaserver_info.
-						       port);
+						g_free
+						    (metaserver_info.port);
 					port = PIONEERS_DEFAULT_META_PORT;
 					if (split_result[2])
 						port = split_result[2];
 					metaserver_info.port =
 					    g_strdup(port);
-					query_meta_server(metaserver_info.
-							  server,
-							  metaserver_info.
-							  port);
+					query_meta_server
+					    (metaserver_info.server,
+					     metaserver_info.port);
 				} else {
 					log_message(MSG_ERROR,
 						    _(""
@@ -710,7 +710,7 @@ static GtkWidget *build_create_interface(void)
 				       "\tThe metaserver does not send information about the games.\n"
 				       "\tPlease set appropriate values yourself."));
 		gtk_widget_show(label);
-		gtk_box_pack_start_defaults(GTK_BOX(vbox), label);
+		gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
 	}
 
 	game_settings = game_settings_new(FALSE);
@@ -733,7 +733,7 @@ static GtkWidget *build_create_interface(void)
 				 0,
 				 game_settings_get_players(GAMESETTINGS
 							   (game_settings))
-				 - 1, 1, 1, 1);
+				 - 1, 1, 4, 0);
 	aiplayers_spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(aiplayers_spin), TRUE);
 	gtk_widget_show(aiplayers_spin);
@@ -998,7 +998,7 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW
 					    (scroll_win), GTK_SHADOW_IN);
 	gtk_widget_show(scroll_win);
-	gtk_box_pack_start_defaults(GTK_BOX(vbox), scroll_win);
+	gtk_box_pack_start(GTK_BOX(vbox), scroll_win, TRUE, TRUE, 0);
 
 	meta_games_model = gtk_list_store_new(META_N_COLUMNS,
 					      G_TYPE_STRING, G_TYPE_STRING,
@@ -1234,7 +1234,7 @@ void connect_create_dlg(void)
 
 	btn = gtk_button_new_with_label(_("Join public game"));
 	gtk_widget_show(btn);
-	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
+	gtk_box_pack_start(GTK_BOX(hbox), btn, TRUE, TRUE, 0);
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(create_meta_dlg), app_window);
 	gtk_widget_set_tooltip_text(btn, _("Join a public game"));
@@ -1243,7 +1243,7 @@ void connect_create_dlg(void)
 
 	btn = gtk_button_new_with_label(_("Create game"));
 	gtk_widget_show(btn);
-	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
+	gtk_box_pack_start(GTK_BOX(hbox), btn, TRUE, TRUE, 0);
 	gtk_widget_set_tooltip_text(btn, _("Create a game"));
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(launch_server_gtk), app_window);
@@ -1256,7 +1256,7 @@ void connect_create_dlg(void)
 
 	btn = gtk_button_new_with_label(_("Join private game"));
 	gtk_widget_show(btn);
-	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
+	gtk_box_pack_start(GTK_BOX(hbox), btn, TRUE, TRUE, 0);
 	gtk_widget_set_tooltip_text(btn, _("Join a private game"));
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(connect_private_dialog), app_window);
@@ -1303,20 +1303,24 @@ static void update_recent_servers_list(void)
 			config_set_string(keyname1, temp_name);
 			config_set_string(keyname2, temp_port);
 		} else {
+			g_free(cur_name);
+			g_free(cur_port);
 			break;
 		}
 
 		if (strlen(cur_name) == 0) {
+			g_free(cur_name);
+			g_free(cur_port);
 			break;
 		}
 
+		g_free(temp_name);
+		g_free(temp_port);
 		if (!strcmp(cur_name, conn_name)
 		    && !strcmp(cur_port, conn_port)) {
 			temp_name = NULL;
 			temp_port = NULL;
 		} else {
-			g_free(temp_name);
-			g_free(temp_port);
 			temp_name = g_strdup(cur_name);
 			temp_port = g_strdup(cur_port);
 		}
@@ -1328,8 +1332,6 @@ static void update_recent_servers_list(void)
 		g_free(cur_name);
 		g_free(cur_port);
 	} while (!done);
-	g_free(cur_name);
-	g_free(cur_port);
 	g_free(temp_name);
 	g_free(temp_port);
 	g_free(conn_name);
