@@ -223,7 +223,7 @@ static GtkActionEntry entries[] = {
 #endif
 	{"PlayerName", NULL, N_("_Player name"), "<control>P",
 	 N_("Change your player name"), playername_cb},
-	{"Legend", GTK_STOCK_DIALOG_INFO, N_("_Legend"), NULL,
+	{"Legend", GTK_STOCK_DIALOG_INFO, N_("L_egend"), NULL,
 	 N_("Terrain legend and building costs"), game_legend_cb},
 	{"GameSettings", GTK_STOCK_DIALOG_INFO, N_("_Game Settings"), NULL,
 	 N_("Settings for the current game"), game_settings_cb},
@@ -461,7 +461,7 @@ static GtkWidget *build_messages_panel(void)
 	scroll_win = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_set_size_request(scroll_win, -1, 80);
 	gtk_widget_show(scroll_win);
-	gtk_box_pack_start_defaults(GTK_BOX(vbox), scroll_win);
+	gtk_box_pack_start(GTK_BOX(vbox), scroll_win, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll_win),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
@@ -571,6 +571,7 @@ static GtkWidget *splash_build_page(void)
 static GtkWidget *build_map_panel(void)
 {
 	GtkWidget *lbl;
+	GtkWidget *legend_content;
 
 	map_notebook = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(map_notebook), GTK_POS_TOP);
@@ -601,7 +602,20 @@ static GtkWidget *build_map_panel(void)
 	/* Tab page name */
 	lbl = gtk_label_new(_("Legend"));
 	gtk_widget_show(lbl);
-	legend_page = legend_create_content();
+	legend_content = legend_create_content();
+
+	legend_page = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(legend_page),
+				       GTK_POLICY_AUTOMATIC,
+				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW
+					    (legend_page),
+					    GTK_SHADOW_NONE);
+	gtk_widget_show(legend_page);
+	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW
+					      (legend_page),
+					      legend_content);
+
 	gtk_notebook_insert_page(GTK_NOTEBOOK(map_notebook),
 				 legend_page, lbl, LEGEND_PAGE);
 	if (!legend_page_enabled)
@@ -1234,8 +1248,8 @@ static void gui_toolbar_show_accelerators(gboolean show_accelerators)
 					gchar *label;
 
 					if (entries[j].accelerator == NULL
-					    || strlen(entries[j].
-						      accelerator)
+					    ||
+					    strlen(entries[j].accelerator)
 					    == 0)
 						label =
 						    g_strdup_printf("%s\n",
@@ -1246,8 +1260,8 @@ static void gui_toolbar_show_accelerators(gboolean show_accelerators)
 						GdkModifierType
 						    accelerator_mods;
 						gtk_accelerator_parse
-						    (entries[j].
-						     accelerator,
+						    (entries
+						     [j].accelerator,
 						     &accelerator_key,
 						     &accelerator_mods);
 						accelerator_text =
@@ -1457,14 +1471,14 @@ static void register_pixmaps(void)
 								  128);
 				resource_pixmap[idx].gcb =
 				    gdk_gc_new(resource_pixmap[idx].b);
-				gdk_gc_set_function(resource_pixmap[idx].
-						    gcb, GDK_OR);
+				gdk_gc_set_function(resource_pixmap
+						    [idx].gcb, GDK_OR);
 				resource_pixmap[idx].gcp =
 				    gdk_gc_new(resource_pixmap[idx].p);
-				gdk_gc_set_clip_mask(resource_pixmap[idx].
-						     gcp,
-						     resource_pixmap[idx].
-						     b);
+				gdk_gc_set_clip_mask(resource_pixmap
+						     [idx].gcp,
+						     resource_pixmap
+						     [idx].b);
 				if (!resource_pixmap_res)
 					resource_pixmap_res =
 					    gdk_pixbuf_get_width(pixbuf);
