@@ -533,10 +533,9 @@ static gboolean check_valid_trade(GtkTreeModel * model,
 		if (quote->is_domestic) {
 			gtk_list_store_set(quoteview->store, iter,
 					   TRADE_COLUMN_POSSIBLE,
-					   quoteview->
-					   check_quote_func(quote) ?
-					   quoteview->true_pixbuf :
-					   quoteview->false_pixbuf, -1);
+					   quoteview->check_quote_func
+					   (quote) ? quoteview->true_pixbuf
+					   : quoteview->false_pixbuf, -1);
 		}
 	return FALSE;
 }
