@@ -618,9 +618,10 @@ WinnableState params_check_winnable_state(const GameParams * params,
 			total_island +=
 			    g_array_index(params->island_discovery_bonus,
 					  gint,
-					  MIN(params->
-					      island_discovery_bonus->len -
-					      1, i));
+					  MIN
+					  (params->
+					   island_discovery_bonus->len - 1,
+					   i));
 			/* The island score can be negative */
 			if (max_island < total_island)
 				max_island = total_island;
