@@ -71,7 +71,11 @@ static void route_event(StateMachine * sm, gint event)
 	StateFunc curr_state;
 	gpointer user_data;
 
-	curr_state = sm_current(sm);
+	if (sm->stack_ptr >= 0)
+		curr_state = sm_current(sm);
+	else
+		curr_state = NULL;
+
 	user_data = sm->user_data;
 	if (user_data == NULL)
 		user_data = sm;
@@ -89,16 +93,18 @@ static void route_event(StateMachine * sm, gint event)
 
 	switch (event) {
 	case SM_ENTER:
-		curr_state(user_data, event);
+		if (curr_state != NULL)
+			curr_state(user_data, event);
 		break;
 	case SM_INIT:
-		curr_state(user_data, event);
+		if (curr_state != NULL)
+			curr_state(user_data, event);
 		if (!sm->is_dead && sm->global !=NULL)
 			sm->global (user_data, event);
 		break;
 	case SM_RECV:
 		sm_cancel_prefix(sm);
-		if (curr_state(user_data, event))
+		if (curr_state != NULL && curr_state(user_data, event))
 			break;
 		sm_cancel_prefix(sm);
 		if (!sm->is_dead
@@ -112,7 +118,8 @@ static void route_event(StateMachine * sm, gint event)
 	case SM_NET_CLOSE:
 		sm_close(sm);
 	default:
-		curr_state(user_data, event);
+		if (curr_state != NULL)
+			curr_state(user_data, event);
 		if (!sm->is_dead && sm->global !=NULL)
 			sm->global (user_data, event);
 		break;
@@ -499,8 +506,8 @@ static void push_new_state(StateMachine * sm)
 	/* check for stack overflows */
 	if (sm->stack_ptr >= G_N_ELEMENTS(sm->stack)) {
 		log_message(MSG_ERROR,
-			    _
-			    ("State stack overflow. Stack dump sent to standard error.\n"));
+			    _(""
+			      "State stack overflow. Stack dump sent to standard error.\n"));
 		sm_stack_dump(sm);
 		g_error("State stack overflow");
 	}
@@ -533,12 +540,20 @@ static void do_goto(StateMachine * sm, StateFunc new_state, gboolean enter)
 	sm_dec_use_count(sm);
 }
 
-void sm_goto(StateMachine * sm, StateFunc new_state)
+void sm_debug(G_GNUC_UNUSED const gchar * function,
+	      G_GNUC_UNUSED const gchar * state)
+{
+#ifdef STACK_DEBUG
+	debug("Call %s with %s\n", function, state);
+#endif
+}
+
+void sm_goto_nomacro(StateMachine * sm, StateFunc new_state)
 {
 	do_goto(sm, new_state, TRUE);
 }
 
-void sm_goto_noenter(StateMachine * sm, StateFunc new_state)
+void sm_goto_noenter_nomacro(StateMachine * sm, StateFunc new_state)
 {
 	do_goto(sm, new_state, FALSE);
 }
@@ -559,12 +574,12 @@ static void do_push(StateMachine * sm, StateFunc new_state, gboolean enter)
 	sm_dec_use_count(sm);
 }
 
-void sm_push(StateMachine * sm, StateFunc new_state)
+void sm_push_nomacro(StateMachine * sm, StateFunc new_state)
 {
 	do_push(sm, new_state, TRUE);
 }
 
-void sm_push_noenter(StateMachine * sm, StateFunc new_state)
+void sm_push_noenter_nomacro(StateMachine * sm, StateFunc new_state)
 {
 	do_push(sm, new_state, FALSE);
 }
