@@ -226,10 +226,12 @@ int main(int argc, char *argv[])
 		return 2;
 	}
 	if (game_file == NULL) {
-		load_game_types(get_pioneers_dir());
-		if (game_title == NULL)
-			params = cfg_set_game("Default");
-		else
+		if (game_title == NULL) {
+			if (num_players > 4)
+				params = cfg_set_game("5/6-player");
+			else
+				params = cfg_set_game("Default");
+		} else
 			params = cfg_set_game(game_title);
 	} else {
 		params = cfg_set_game_file(game_file);
@@ -305,7 +307,6 @@ int main(int argc, char *argv[])
 	g_free(admin_port);
 	g_option_context_free(context);
 	params_free(params);
-	server_cleanup_static_data();
 	return 0;
 }
 
