@@ -243,12 +243,12 @@ Game *server_start(const GameParams * params, const gchar * hostname,
 gboolean server_stop(Game * game);
 gboolean server_is_running(Game * game);
 gint accept_connection(gint in_fd, gchar ** location);
-void server_cleanup_static_data(void);
 
 /**** game list control functions ****/
+void game_list_prepare(void);
 const GameParams *game_list_find_item(const gchar * title);
 void game_list_foreach(GFunc func, gpointer user_data);
-void load_game_types(const gchar * path);
+void game_list_cleanup(void);
 
 /**** callbacks to set parameters ****/
 GameParams *cfg_set_game(const gchar * game);
