@@ -247,14 +247,12 @@ static void build_add(Player * player, BuildType type, gint x, gint y,
 
 			if (points != 0)
 				special_points =
-				    points_new(player->
-					       special_points_next_id++,
-					       first_island ?
-					       N_("Island Discovery Bonus")
-					       :
-					       N_(""
-						  "Additional Island Bonus"),
-					       points);
+				    points_new
+				    (player->special_points_next_id++,
+				     first_island ?
+				     N_("Island Discovery Bonus")
+				     : N_("" "Additional Island Bonus"),
+				     points);
 			player->islands_discovered++;
 		}
 	}
